==> scsh-0.3.tar.gz: scsh-0.3/scsh/irix/signals.scm <==
;;; Signal constant definitions for "irix"
;;; Copyright (c) 1994 by Olin Shivers.
;;; Copyright (c) 1994 by Brian D. Carlstrom.

(define-syntax define-signals
  (syntax-rules ()
    ((define-signals form ...)
     (begin (define-enum-constant "signal" . form) ...))))

;;POSIX only defined here.

(define-signals
  ;; POSIX
  (hup	1)	; hangup 
  (int	2)	; interrupt 
  (quit	3)	; quit 
  (ill	4)	; illegal instruction (not reset when caught) 
  (iot	6)	; IOT instruction 
  (abrt 6)	; used by abort, replace SIGIOT in the future 
  (fpe	8)	; floating point exception 
  (kill	9)	; kill (cannot be caught or ignored) 
  (bus  10)	; bus error
  (segv	11)	; segmentation violation
  (sys  12)	; bad argument to system call
  (pipe	13)	; write on a pipe with no one to read it 
  (alrm	14)	; alarm clock 
  (term	15)	; software termination signal from kill 
  (stop	20)	; sendable stop signal not from tty 
  (tstp	21)	; stop signal from tty 
  (cont	28)	; continue a stopped process 
  (chld	18)	; to parent on child stop or exit 
  (cld	18)	; compat
  (ttin	29)	; to readers pgrp upon background tty read 
  (ttou	30)	; like TTIN for output if (tp->t_local&LTOSTOP) 
  ;; User defined
  (usr1 16)	; user defined signal 1 
  (usr2 17)	; user defined signal 2 

  (pwr  19)	; power-fail restart
  (poll 22)	; pollable event occurred
  (io	23)	; input/output possible signal
  (urg	24)	; urgent condition on io channel
  (winch 25)	; window size changes
  (vtalrm 26)	; virtual time alarm
  (prof	27)	; profiling alarm
  (xcpu	31)	; Cpu time limit exceeded
  (xfsz	32)	; Filesize limit exceeded
  )

==> scsh_0.5.1.orig.tar.gz: scsh-0.5.1.orig/scsh/irix/signals.scm <==
;;; Signal constant definitions for "irix"
;;; Copyright (c) 1994 by Olin Shivers.
;;; Copyright (c) 1994 by Brian D. Carlstrom.

;;POSIX only defined here.

(define-enum-constants signal
  ;; POSIX
  (hup	1)	; hangup 
  (int	2)	; interrupt 
  (quit	3)	; quit 
  (ill	4)	; illegal instruction (not reset when caught) 
  (iot	6)	; IOT instruction 
  (abrt 6)	; used by abort, replace SIGIOT in the future 
  (fpe	8)	; floating point exception 
  (kill	9)	; kill (cannot be caught or ignored) 
  (bus  10)	; bus error
  (segv	11)	; segmentation violation
  (sys  12)	; bad argument to system call
  (pipe	13)	; write on a pipe with no one to read it 
  (alrm	14)	; alarm clock 
  (term	15)	; software termination signal from kill 
  (stop	20)	; sendable stop signal not from tty 
  (tstp	21)	; stop signal from tty 
  (cont	28)	; continue a stopped process 
  (chld	18)	; to parent on child stop or exit 
  (cld	18)	; compat
  (ttin	29)	; to readers pgrp upon background tty read 
  (ttou	30)	; like TTIN for output if (tp->t_local&LTOSTOP) 
  ;; User defined
  (usr1 16)	; user defined signal 1 
  (usr2 17)	; user defined signal 2 

  (pwr  19)	; power-fail restart
  (poll 22)	; pollable event occurred
  (io	23)	; input/output possible signal
  (urg	24)	; urgent condition on io channel
  (winch 25)	; window size changes
  (vtalrm 26)	; virtual time alarm
  (prof	27)	; profiling alarm
  (xcpu	31)	; Cpu time limit exceeded
  (xfsz	32)	; Filesize limit exceeded
  )

(define signals-ignored-by-default
  (list signal/chld signal/cont				 ; These are Posix.
	signal/pwr signal/poll signal/urg signal/winch)) ; These are Irix.
